@@ -19,18 +19,22 @@ import yaml
 from typing import List
 from kafka import KafkaConsumer
 from kafka import KafkaProducer
+from cerberus import Validator
 
 from cloud_builder.defaults import Defaults
 from cloud_builder.package_request.package_request import CBPackageRequest
 from cloud_builder.info_request.info_request import CBInfoRequest
 from cloud_builder.response.response import CBResponse
 from cloud_builder.info_response.info_response import CBInfoResponse
-from cloud_builder.cloud_logger import CBCloudLogger
 from cloud_builder.broker.base import CBMessageBrokerBase
+from cloud_builder.config.cloud_builder_broker_schema import (
+    cloud_builder_broker_schema
+)
 
 from cloud_builder.exceptions import (
     CBKafkaProducerException,
-    CBKafkaConsumerException
+    CBKafkaConsumerException,
+    CBConfigFileValidationError
 )
 
 
@@ -47,8 +51,15 @@ class CBMessageBrokerKafka(CBMessageBrokerBase):
         .. code:: yaml
             host: kafka-example.com:12345
         """
-        self.log = CBCloudLogger('CBMessageBrokerKafka', '(system)')
-        self.kafka_host = self.config['host']
+        validator = Validator(cloud_builder_broker_schema)
+        validator.validate(self.config, cloud_builder_broker_schema)
+        if validator.errors:
+            raise CBConfigFileValidationError(
+                'ValidationError for {0!r}: {1!r}'.format(
+                    self.config, validator.errors
+                )
+            )
+        self.kafka_host = self.config['broker']['host']
         self.consumer: KafkaConsumer = None
         self.producer: KafkaProducer = None
 
@@ -65,7 +76,7 @@ class CBMessageBrokerKafka(CBMessageBrokerBase):
         self._create_producer()
         message = yaml.dump(request.get_data()).encode()
         self.producer.send(
-            Defaults.get_package_request_queue_name(), message
+            request.get_data()['runner_group'], message
         ).add_callback(self._on_send_success).add_errback(self._on_send_error)
         self.producer.flush()
 
@@ -127,6 +138,19 @@ class CBMessageBrokerKafka(CBMessageBrokerBase):
         if self.consumer:
             self.consumer.commit()
 
+    def get_runner_group(self) -> str:
+        """
+        Return runner identification for package build requests.
+        In kafka this is the topic name of the request queue
+
+        :return: kafka topic name
+
+        :rtype: str
+        """
+        if self.config.get('runner'):
+            return self.config['runner']['group']
+        return Defaults.get_package_request_queue_name()
+
     def close(self) -> None:
         """
         Close connection to message system
